==> groovy_1.5.6.orig.tar.gz: groovy-1.5.6.orig/src/main/org/codehaus/groovy/ast/stmt/CaseStatement.java <==
/*
 * Copyright 2003-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.codehaus.groovy.ast.stmt;

import org.codehaus.groovy.ast.GroovyCodeVisitor;
import org.codehaus.groovy.ast.expr.Expression;


/**
 * Represents a case statement in a switch statement
 * 
 * @author <a href="mailto:james@coredevelopers.net">James Strachan</a>
 * @version $Revision: 7922 $
 */
public class CaseStatement extends Statement {

    private final Statement code;
    private Expression expression;
    
    public CaseStatement(Expression expression, Statement code) {
        this.expression = expression;
        this.code = code;
    }
    
    public Statement getCode() {
        return code;
    }
    
    public Expression getExpression() {
        return expression;
    }
    
    public void setExpression(Expression e) {
        expression=e;
    }

    public void visit(GroovyCodeVisitor visitor) {
        visitor.visitCaseStatement(this);
    }
    
    public String toString() {
        return super.toString() + "[expression: " + expression + "; code: " + code + "]";
    }
}

==> groovy_1.6.3.orig.tar.gz: groovy-1.6.3.orig/src/main/org/codehaus/groovy/ast/stmt/CaseStatement.java <==
/*
 * Copyright 2003-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.codehaus.groovy.ast.stmt;

import org.codehaus.groovy.ast.GroovyCodeVisitor;
import org.codehaus.groovy.ast.expr.Expression;


/**
 * Represents a case statement in a switch statement
 * 
 * @author <a href="mailto:james@coredevelopers.net">James Strachan</a>
 * @version $Revision: 15760 $
 */
public class CaseStatement extends Statement {

    private Statement code;
    private Expression expression;
    
    public CaseStatement(Expression expression, Statement code) {
        this.expression = expression;
        this.code = code;
    }
    
    public Statement getCode() {
        return code;
    }

    public void setCode(Statement code) {
        this.code = code;
    }

    public Expression getExpression() {
        return expression;
    }
    
    public void setExpression(Expression e) {
        expression=e;
    }

    public void visit(GroovyCodeVisitor visitor) {
        visitor.visitCaseStatement(this);
    }
    
    public String toString() {
        return super.toString() + "[expression: " + expression + "; code: " + code + "]";
    }
}
